<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Test App</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/2.1.4/jquery.min.js" type="text/javascript"></script>
    {% block extracss %}{% endblock %}
</head>
<body>
    {% block main %}{% endblock %}
    {% block extrajs %}{% endblock %}
</body>
</html>